..
    This file is part of Invenio.
    Copyright (C) 2016-2018 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

Contributors
============

- Alexander Ioannidis
- Alizee Pace
- Chiara Bigarella
- Diego Rodriguez
- Harris Tzovanakis
- Javier Martin Montull
- Jiri Kuncar
- Krzysztof Nowak
- Lars Holm Nielsen
- Leonardo Rossi
- Nicolas Harraudeau
- Nikos Filippakis
- Paulina Lach
- Salvatore Zaza
- Sebastian Witowski
- Tibor Simko
